@@ -1,3 +1,22 @@
+/*
+ * yellownotes-applet: a maemo home applet for yellow notes
+ * Copyright (C) 2007-2010 Gabriel Nava <gabriel.nava@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option); any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #include <gtk/gtk.h>
 #include <hildon/hildon.h>
 #include <stdlib.h>
@@ -392,7 +411,7 @@ void set_cairo_transparency(GdkDrawable *drawable, GdkEventExpose *event, GdkCol
 	cairo_clip (cr);
 
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-	cairo_set_source_rgba (cr, color.red, color.green, color.blue, alpha);
+	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, alpha);
 	cairo_paint (cr);
   
 	cairo_destroy (cr);
@@ -430,8 +449,8 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app)
 	GtkWidget *button=NULL;
 	GtkWidget *fbutton=NULL;
 	GtkWidget *fcbutton=NULL;
-	gchar value[4];
 
+	gchar value[4];
 	gint response=0;
 
 	dialog=gtk_dialog_new_with_buttons("Configuration",NULL, GTK_DIALOG_MODAL, GTK_STOCK_OK,GTK_RESPONSE_ACCEPT,GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,NULL);
@@ -616,7 +635,6 @@ void build_ui (void)
 
 static void yellownotes_plugin_init (YellowNotesPlugin *desktop_plugin)
 {
-
 	app = g_new0 (YNCtx, 1);
 
 	load_applet_prefs(app);
@@ -650,27 +668,13 @@ static void yellownotes_plugin_realize (GtkWidget *widget)
 
         screen = gtk_widget_get_screen (widget);
         gtk_widget_set_colormap (widget,gdk_screen_get_rgba_colormap (screen));
-
         gtk_widget_set_app_paintable (widget,TRUE);
 
         GTK_WIDGET_CLASS (yellownotes_plugin_parent_class)->realize (widget);
-
 }
 
 static gboolean yellownotes_plugin_expose_event(GtkWidget *widget, GdkEventExpose *event)
 {
-	cairo_t *cr;
-
-	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-	gdk_cairo_region (cr, event->region);
-	cairo_clip (cr);
-
-	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-	cairo_set_source_rgba (cr, (app->color).red, (app->color).green, (app->color).blue, app->bg_alpha);
-	cairo_paint (cr);
-  
-	cairo_destroy (cr);
-
+	set_cairo_transparency(GDK_DRAWABLE (widget->window),event,app->color,app->bg_alpha);
 	return GTK_WIDGET_CLASS (yellownotes_plugin_parent_class)->expose_event (widget,event);
-
 }
